
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#pragma once

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "cairo-utils.h" */

GType cairo_metadata_flags_t_cairo_metadata_flags_t_get_type (void);
#define CAIRO_METADATA_FLAGS_T_TYPE_CAIRO_METADATA_FLAGS_T (cairo_metadata_flags_t_cairo_metadata_flags_t_get_type())

GType item_style_get_type (void);
#define ITEM_TYPE_STYLE (item_style_get_type())

/* enumerations from "dom.h" */

GType dom_error_enum_get_type (void);
#define DOM_TYPE_ERROR_ENUM (dom_error_enum_get_type())

/* enumerations from "gio-utils.h" */

GType gth_list_flags_get_type (void);
#define GTH_TYPE_LIST_FLAGS (gth_list_flags_get_type())

/* enumerations from "gnome-desktop-thumbnail.h" */

GType gnome_desktop_thumbnail_size_get_type (void);
#define GNOME_TYPE_DESKTOP_THUMBNAIL_SIZE (gnome_desktop_thumbnail_size_get_type())

/* enumerations from "gsignature.h" */

GType g_signature_enc_get_type (void);
#define G_TYPE_SIGNATURE_ENC (g_signature_enc_get_type())

/* enumerations from "gth-browser.h" */

GType gth_action_get_type (void);
#define GTH_TYPE_ACTION (gth_action_get_type())

GType gth_scroll_action_get_type (void);
#define GTH_TYPE_SCROLL_ACTION (gth_scroll_action_get_type())

/* enumerations from "gth-color-scale.h" */

GType gth_color_scale_type_get_type (void);
#define GTH_TYPE_COLOR_SCALE_TYPE (gth_color_scale_type_get_type())

/* enumerations from "gth-error.h" */

GType gth_error_code_get_type (void);
#define GTH_TYPE_ERROR_CODE (gth_error_code_get_type())

/* enumerations from "gth-file-list.h" */

GType gth_file_list_mode_get_type (void);
#define GTH_TYPE_FILE_LIST_MODE (gth_file_list_mode_get_type())

/* enumerations from "gth-file-view.h" */

GType gth_visibility_get_type (void);
#define GTH_TYPE_VISIBILITY (gth_visibility_get_type())

GType gth_file_view_renderer_type_get_type (void);
#define GTH_TYPE_FILE_VIEW_RENDERER_TYPE (gth_file_view_renderer_type_get_type())

/* enumerations from "gth-filter.h" */

GType gth_limit_type_get_type (void);
#define GTH_TYPE_LIMIT_TYPE (gth_limit_type_get_type())

/* enumerations from "gth-folder-tree.h" */

GType gth_folder_tree_sort_get_type (void);
#define GTH_TYPE_FOLDER_TREE_SORT (gth_folder_tree_sort_get_type())

/* enumerations from "gth-grid-view.h" */

GType gth_cursor_movement_get_type (void);
#define GTH_TYPE_CURSOR_MOVEMENT (gth_cursor_movement_get_type())

GType gth_drop_position_get_type (void);
#define GTH_TYPE_DROP_POSITION (gth_drop_position_get_type())

GType gth_selection_change_get_type (void);
#define GTH_TYPE_SELECTION_CHANGE (gth_selection_change_get_type())

/* enumerations from "gth-histogram-view.h" */

GType gth_histogram_mode_get_type (void);
#define GTH_TYPE_HISTOGRAM_MODE (gth_histogram_mode_get_type())

GType gth_histogram_scale_get_type (void);
#define GTH_TYPE_HISTOGRAM_SCALE (gth_histogram_scale_get_type())

/* enumerations from "gth-histogram.h" */

GType gth_histogram_channel_get_type (void);
#define GTH_TYPE_HISTOGRAM_CHANNEL (gth_histogram_channel_get_type())

/* enumerations from "gth-image-selector.h" */

GType gth_selector_type_get_type (void);
#define GTH_TYPE_SELECTOR_TYPE (gth_selector_type_get_type())

/* enumerations from "gth-image-viewer.h" */

GType gth_zoom_quality_get_type (void);
#define GTH_TYPE_ZOOM_QUALITY (gth_zoom_quality_get_type())

GType gth_fit_get_type (void);
#define GTH_TYPE_FIT (gth_fit_get_type())

GType gth_zoom_change_get_type (void);
#define GTH_TYPE_ZOOM_CHANGE (gth_zoom_change_get_type())

GType gth_transparency_style_get_type (void);
#define GTH_TYPE_TRANSPARENCY_STYLE (gth_transparency_style_get_type())

/* enumerations from "gth-image.h" */

GType gth_image_format_get_type (void);
#define GTH_TYPE_IMAGE_FORMAT (gth_image_format_get_type())

/* enumerations from "gth-metadata-provider.h" */

GType gth_metadata_write_flags_get_type (void);
#define GTH_TYPE_METADATA_WRITE_FLAGS (gth_metadata_write_flags_get_type())

/* enumerations from "gth-metadata.h" */

GType gth_metadata_type_get_type (void);
#define GTH_TYPE_METADATA_TYPE (gth_metadata_type_get_type())

GType gth_metadata_flags_get_type (void);
#define GTH_TYPE_METADATA_FLAGS (gth_metadata_flags_get_type())

/* enumerations from "gth-monitor.h" */

GType gth_monitor_event_get_type (void);
#define GTH_TYPE_MONITOR_EVENT (gth_monitor_event_get_type())

/* enumerations from "gth-overwrite-dialog.h" */

GType gth_overwrite_response_get_type (void);
#define GTH_TYPE_OVERWRITE_RESPONSE (gth_overwrite_response_get_type())

/* enumerations from "gth-sidebar.h" */

GType gth_sidebar_state_get_type (void);
#define GTH_TYPE_SIDEBAR_STATE (gth_sidebar_state_get_type())

/* enumerations from "gth-statusbar.h" */

GType gth_statusbar_section_get_type (void);
#define GTH_TYPE_STATUSBAR_SECTION (gth_statusbar_section_get_type())

/* enumerations from "gth-tags-entry.h" */

GType gth_tags_entry_mode_get_type (void);
#define GTH_TYPE_TAGS_ENTRY_MODE (gth_tags_entry_mode_get_type())

/* enumerations from "gth-task.h" */

GType gth_task_flags_get_type (void);
#define GTH_TYPE_TASK_FLAGS (gth_task_flags_get_type())

GType gth_task_error_enum_get_type (void);
#define GTH_TYPE_TASK_ERROR_ENUM (gth_task_error_enum_get_type())

/* enumerations from "gth-template-selector.h" */

GType gth_template_code_type_get_type (void);
#define GTH_TYPE_TEMPLATE_CODE_TYPE (gth_template_code_type_get_type())

/* enumerations from "gth-test-chain.h" */

GType gth_match_type_get_type (void);
#define GTH_TYPE_MATCH_TYPE (gth_match_type_get_type())

/* enumerations from "gth-test-simple.h" */

GType gth_test_data_type_get_type (void);
#define GTH_TYPE_TEST_DATA_TYPE (gth_test_data_type_get_type())

/* enumerations from "gth-test.h" */

GType gth_match_get_type (void);
#define GTH_TYPE_MATCH (gth_match_get_type())

GType gth_test_op_get_type (void);
#define GTH_TYPE_TEST_OP (gth_test_op_get_type())

/* enumerations from "gth-toolbox.h" */

GType gth_toolbox_section_get_type (void);
#define GTH_TYPE_TOOLBOX_SECTION (gth_toolbox_section_get_type())

/* enumerations from "gth-user-dir.h" */

GType gth_dir_get_type (void);
#define GTH_TYPE_DIR (gth_dir_get_type())

/* enumerations from "pixbuf-cache.h" */

GType pixbuf_cache_channel_get_type (void);
#define PIXBUF_TYPE_CACHE_CHANNEL (pixbuf_cache_channel_get_type())

/* enumerations from "str-utils.h" */

GType template_flags_get_type (void);
#define TEMPLATE_TYPE_FLAGS (template_flags_get_type())

/* enumerations from "typedefs.h" */

GType gth_click_policy_get_type (void);
#define GTH_TYPE_CLICK_POLICY (gth_click_policy_get_type())

GType gth_direction_get_type (void);
#define GTH_TYPE_DIRECTION (gth_direction_get_type())

GType gth_transform_get_type (void);
#define GTH_TYPE_TRANSFORM (gth_transform_get_type())

GType gth_unit_get_type (void);
#define GTH_TYPE_UNIT (gth_unit_get_type())

GType gth_metric_get_type (void);
#define GTH_TYPE_METRIC (gth_metric_get_type())

GType gth_aspect_ratio_get_type (void);
#define GTH_TYPE_ASPECT_RATIO (gth_aspect_ratio_get_type())

GType gth_overwrite_mode_get_type (void);
#define GTH_TYPE_OVERWRITE_MODE (gth_overwrite_mode_get_type())

GType gth_grid_type_get_type (void);
#define GTH_TYPE_GRID_TYPE (gth_grid_type_get_type())

GType gth_thumbnail_state_get_type (void);
#define GTH_TYPE_THUMBNAIL_STATE (gth_thumbnail_state_get_type())

/* enumerations from "uri-utils.h" */

GType uri_part_get_type (void);
#define URI_TYPE_PART (uri_part_get_type())

G_END_DECLS

/* Generated data ends here */

