/* Do not edit.  Autogenerated from src/gthumb.h.in */

/*
 *  GThumb
 *
 *  Copyright (C) 2009 The Free Software Foundation, Inc.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
#ifndef GTHUMB_H
#define GTHUMB_H

#include <gth-enum-types.h>
#include <gth-marshal.h>
#include <cairo-scale.h>
#include <cairo-utils.h>
#include <color-utils.h>
#include <dom.h>
#include <gfixed.h>
#include <gimp-op.h>
#include <gio-utils.h>
#include <glib-utils.h>
#include <gnome-desktop-thumbnail.h>
#include <gsignature.h>
#include <gth-accel-button.h>
#include <gth-accel-dialog.h>
#include <gth-auto-paned.h>
#include <gth-async-task.h>
#include <gth-buffer-data.h>
#include <gth-browser.h>
#include <gth-color-manager.h>
#include <gth-color-scale.h>
#include <gth-delete-task.h>
#include <gth-duplicable.h>
#include <gth-empty-list.h>
#include <gth-extensions.h>
#include <gth-file-chooser-dialog.h>
#include <gth-error.h>
#include <gth-file-data.h>
#include <gth-file-list.h>
#include <gth-file-properties.h>
#include <gth-file-selection.h>
#include <gth-file-selection-info.h>
#include <gth-file-source.h>
#include <gth-file-source-vfs.h>
#include <gth-file-store.h>
#include <gth-file-tool.h>
#include <gth-file-view.h>
#include <gth-filter.h>
#include <gth-filterbar.h>
#include <gth-filter-editor-dialog.h>
#include <gth-filter-file.h>
#include <gth-filter-grid.h>
#include <gth-folder-tree.h>
#include <gth-grid-view.h>
#include <gth-histogram.h>
#include <gth-histogram-view.h>
#include <gth-hook.h>
#include <gth-icc-profile.h>
#include <gth-icon-cache.h>
#include <gth-image.h>
#include <gth-image-dragger.h>
#include <gth-image-history.h>
#include <gth-image-list-task.h>
#include <gth-image-loader.h>
#include <gth-image-navigator.h>
#include <gth-image-overview.h>
#include <gth-image-preloader.h>
#include <gth-image-saver.h>
#include <gth-image-selector.h>
#include <gth-image-task.h>
#include <gth-image-task-chain.h>
#include <gth-image-utils.h>
#include <gth-image-viewer.h>
#include <gth-image-viewer-tool.h>
#include <gth-info-bar.h>
#include <gth-load-file-data-task.h>
#include <gth-location-bar.h>
#include <gth-location-chooser.h>
#include <gth-location-chooser-dialog.h>
#include <gth-main.h>
#include <gth-menu-manager.h>
#include <gth-metadata.h>
#include <gth-metadata-chooser.h>
#include <gth-metadata-provider.h>
#include <gth-monitor.h>
#include <gth-overwrite-dialog.h>
#include <gth-paned.h>
#include <gth-preferences.h>
#include <gth-progress-dialog.h>
#include <gth-property-view.h>
#include <gth-request-dialog.h>
#include <gth-save-file-data-task.h>
#include <gth-save-image-task.h>
#include <gth-screensaver.h>
#include <gth-shortcut.h>
#include <gth-sidebar.h>
#include <gth-sidebar-section.h>
#include <gth-statusbar.h>
#include <gth-string-list.h>
#include <gth-tags-entry.h>
#include <gth-tags-file.h>
#include <gth-template-editor-dialog.h>
#include <gth-template-selector.h>
#include <gth-task.h>
#include <gth-test.h>
#include <gth-test-aspect-ratio.h>
#include <gth-test-category.h>
#include <gth-test-chain.h>
#include <gth-test-selector.h>
#include <gth-test-simple.h>
#include <gth-thumb-loader.h>
#include <gth-time.h>
#include <gth-time-selector.h>
#include <gth-toolbox.h>
#include <gth-uri-list.h>
#include <gth-user-dir.h>
#include <gth-vfs-tree.h>
#include <gth-viewer-page.h>
#include <gth-window.h>
#include <gtk-utils.h>
#include <gvaluehash.h>
#include <pixbuf-cache.h>
#include <pixbuf-io.h>
#include <pixbuf-utils.h>
#include <str-utils.h>
#include <typedefs.h>
#include <uri-utils.h>
#include <zlib-utils.h>

#endif /* GTHUMB_H */
